@@ -1,4 +1,4 @@
-from imblearn.over_sampling import RandomOverSampler
+from imblearn.over_sampling import RandomOverSampler, SMOTE
 
 
 # Function for data normalization
@@ -15,22 +15,20 @@ def normalize(col, df, method):
 
 # Function to manage oversampling method
 def oversampling(df, method, ycol):
+    global oversampling_method
+
+    # Establish X and Y columns for the operation
+    x = df.drop(ycol, axis=1)
+    y = df[ycol]
+
     if method == "random":
-        df = randomOverSampling(df, ycol)
+        oversampling_method = RandomOverSampler(sampling_strategy='minority')
     elif method == "smote":
-        df = SMOTE(df, ycol)
-    return df
+        oversampling_method = SMOTE(sampling_strategy='minority')
 
-
-# Perform random oversampling of the dataframe
-def randomOverSampling(df, ycol):
-    oversampler = RandomOverSampler(sampling_strategy='minority')
-    X = df.loc[:, df.columns != ycol]
-    Y = df[ycol]
+    # Execute imblearn random oversampling method
+    x_ov, y_ov = oversampling_method.fit_resample(x, y)
+    x_ov[ycol] = y_ov
 
     return df
 
-
-# Perform SMOTE in the dataframe
-def SMOTE(df, ycol):
-    return df
